@@ -1,5 +1,5 @@
 # 导入到包的__init__.py文件中，使得外部可以直接导入包名即可使用包中的函数
-from .api import (
+from mw_python_sdk.api import (
     upload_file,
     download_file,
     download_dir,
@@ -7,9 +7,12 @@ from .api import (
     create_dataset,
     delete_dataset,
     upload_folder,
-    list_datasets,
-    list_all_datasets,
     get_dataset,
     create_commit,
     DatasetConstructor,
 )
+
+from mw_python_sdk.api_list import (
+    list_datasets,
+    list_all_datasets,
+)
