@@ -36,7 +36,7 @@ import random
 import string
 from dataclasses import dataclass, field
 from urllib.parse import quote
-from typing import BinaryIO, Dict, List, Optional, Set, Union
+from typing import BinaryIO, Dict, List, Optional, Set, Union, Callable
 import boto3  # type: ignore
 import sseclient
 from boto3.s3.transfer import TransferConfig
@@ -65,6 +65,8 @@ load_dotenv()  # take environment variables from local .env
 HEYWHALE_SITE = os.getenv("HEYWHALE_HOST", "https://www.heywhale.com")
 HEYWHALE_DS_BUCKET = os.getenv("HEYWHALE_DS_BUCKET", "kesci")
 
+def win_to_linux_path(win_path):
+    return win_path.replace('\\', '/')
 
 @dataclass(frozen=True)
 class DatasetFileForUpload:
@@ -125,7 +127,9 @@ class DatasetConstructor:
                 path_in_dataset = os.path.join(remote_dir, rel_path)
                 self.add_file(file_path, path_in_dataset)
 
-    def push_dataset(self) -> Dataset:
+    def push_dataset(
+        self, hook: Optional[Callable[[str, str], None]] = None
+    ) -> Dataset:
         """
         将数据集推送到平台并返回数据集对象。
 
@@ -142,6 +146,7 @@ class DatasetConstructor:
             title=self.title,
             files=list(self.data_files),
             short_description=self.short_description,
+            hook=hook,
         )
         if dataset is None:
             raise ValueError("Failed to create dataset")
@@ -330,15 +335,15 @@ def _upload_file(
 
     bucket_name = upload_info.bucket
 
-    object_key = os.path.join(
+    object_key = win_to_linux_path(os.path.join(
         upload_info.prefix_to_save, generate_timestamped_string(1)
-    )
+    ))
     if path_in_dataset != "":
         # get base filename from path_in_dataset
         # 前端是在对象存储中key没有带目录的
         # 目录存在api的SubPath字段里面
         # 这里仿照前端的格式存以防有什么不统一的地方导致错误
-        object_key = os.path.join(object_key, os.path.basename(path_in_dataset))
+        object_key = win_to_linux_path(os.path.join(object_key, os.path.basename(path_in_dataset)))
     try:
         if isinstance(path_or_fileobj, (str, Path)):
             # s3 大小限制，使用multipart上传。
@@ -595,6 +600,8 @@ def _download_single_file_by_cached(
         blob_path = r.json().get("cachedFilePath")
     logger.debug("cached blob file path: %s", blob_path)
     slk_path.parent.mkdir(parents=True, exist_ok=True)
+    if slk_path.exists():
+        slk_path.unlink()
     slk_path.symlink_to(blob_path)
     return slk_path
 
@@ -659,9 +666,11 @@ def _download_single_file(
             for chunk in response.iter_content(chunk_size=chunk_size):
                 file.write(chunk)
                 seen_so_far += len(chunk)
-                print_percent(str(file_path), seen_so_far, total_size)
+                print_percent(str(slk_path), seen_so_far, total_size)
             file_path.rename(file_path.parent.joinpath(etag))
     slk_path.parent.mkdir(parents=True, exist_ok=True)
+    if slk_path.exists():
+        slk_path.unlink()
     slk_path.symlink_to(blob_path)
     return slk_path
 
@@ -1023,6 +1032,7 @@ def _create_dataset(
     folder_name: Optional[str] = None,
     token: Optional[str] = None,
     enable_download: bool = True,
+    hook: Optional[Callable[[str, str], None]] = None,
 ) -> Optional[Dataset]:
     """Creates a dataset
 
@@ -1048,8 +1058,12 @@ def _create_dataset(
     if upload_info is None:
         raise ValueError("Failed to get upload token.")
     for file in files:
+        if hook is not None:
+            hook("Uploading", file.local_path)
         object_key = _upload_file(file.local_path, file.remote_path, upload_info)
-        sub_path = _norm_path(str(Path(file.remote_path).parent))
+        if hook is not None:
+            hook("Uploaded", file.local_path)
+        sub_path = _norm_path(win_to_linux_path(str(Path(file.remote_path).parent)))
         dataset_files.append(
             DatasetFile(_id="", size=0, key=object_key, sub_path=sub_path)
         )
