@@ -1,4 +1,6 @@
 import typer
+import asyncio
+import requests
 
 llm = typer.Typer(short_help="The LLM management.")
 
@@ -33,6 +35,49 @@ def serve(
         enforce_eager=enforce_eager,
     )
 
+@llm.command(short_help="Bench an online serving model.")
+def bench(
+    base_url: str = typer.Option("http://127.0.0.1:8000", help="The base URL of the model."),
+    model: str = typer.Option(None, help="The ID of the model to use."),
+    tokenizer: str = typer.Option("", help="The tokenizer path to use."),
+    dataset_name: str = typer.Option("sharegpt", help="The dataset name to use."),
+    dataset_path: str = typer.Option("", help="The dataset path to use."),
+    backend: str = typer.Option("vllm", help="The backend to use."),
+    share_gpt_context_length: int = typer.Option(4096, help="The shared GPT context length."),
+    num_prompts: int = typer.Option(1000, help="The number of prompts to use."),
+    output_len: int = typer.Option(None, help="The output length."),
+    request_rate: float = typer.Option(float("inf"), help="The request rate."),
+    max_concurrency: int = typer.Option(None, help="The maximum concurrency."),
+    disable_tqdm: bool = typer.Option(False, help="Whether to disable tqdm."),
+):
+    from mw_python_sdk.llm.bench import benchmark, set_ulimit, get_tokenizer,get_dataset
+    set_ulimit()
+    api_url = f"{base_url}/v1/completions"
+    model_url = f"{base_url}/v1/models"
+    if model is None:
+        response = requests.get(model_url, timeout=10)
+        model_list = response.json().get("data", [])
+        model = model_list[0]["id"] if model_list else None
+    print(f"Using tokenzier: {tokenizer}")
+    print(f"Get dataset {dataset_name} from {dataset_path}")
+    tkzr = get_tokenizer(tokenizer)
+    input_requests = get_dataset(dataset_name, dataset_path, num_prompts, share_gpt_context_length, output_len, tkzr)
+    asyncio.run(
+            benchmark(
+                backend=backend,
+                api_url=api_url,
+                base_url=base_url,
+                model_id=model,
+                tokenizer=tkzr,
+                input_requests=input_requests,
+                request_rate=request_rate,
+                max_concurrency=max_concurrency,
+                disable_tqdm=disable_tqdm,
+                lora_name="",
+                extra_request_body=dict(),
+                profile=False,
+            )
+        )
 
 datasets = typer.Typer(short_help="The datasets management.")
 
